=======
GroupBy
=======

This namespace comes available by calling `LazyFrame.groupby(..)`.

.. currentmodule:: polars.internals.lazyframe.groupby

.. autosummary::
   :toctree: api/

    LazyGroupBy.agg
    LazyGroupBy.apply
    LazyGroupBy.head
    LazyGroupBy.tail
